==> istio-model-v1beta1-5.12.1-sources.jar: io/fabric8/istio/api/security/v1beta1/SourceBuilder.java <==
package io.fabric8.istio.api.security.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SourceBuilder extends io.fabric8.istio.api.security.v1beta1.SourceFluentImpl<io.fabric8.istio.api.security.v1beta1.SourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.istio.api.security.v1beta1.Source,io.fabric8.istio.api.security.v1beta1.SourceBuilder>{
  public SourceBuilder() {
    this(false);
  }
  public SourceBuilder(java.lang.Boolean validationEnabled) {
    this(new Source(), validationEnabled);
  }
  public SourceBuilder(io.fabric8.istio.api.security.v1beta1.SourceFluent<?> fluent) {
    this(fluent, false);
  }
  public SourceBuilder(io.fabric8.istio.api.security.v1beta1.SourceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Source(), validationEnabled);
  }
  public SourceBuilder(io.fabric8.istio.api.security.v1beta1.SourceFluent<?> fluent,io.fabric8.istio.api.security.v1beta1.Source instance) {
    this(fluent, instance, false);
  }
  public SourceBuilder(io.fabric8.istio.api.security.v1beta1.SourceFluent<?> fluent,io.fabric8.istio.api.security.v1beta1.Source instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withIpBlocks(instance.getIpBlocks()); 
    fluent.withNamespaces(instance.getNamespaces()); 
    fluent.withNotIpBlocks(instance.getNotIpBlocks()); 
    fluent.withNotNamespaces(instance.getNotNamespaces()); 
    fluent.withNotPrincipals(instance.getNotPrincipals()); 
    fluent.withNotRemoteIpBlocks(instance.getNotRemoteIpBlocks()); 
    fluent.withNotRequestPrincipals(instance.getNotRequestPrincipals()); 
    fluent.withPrincipals(instance.getPrincipals()); 
    fluent.withRemoteIpBlocks(instance.getRemoteIpBlocks()); 
    fluent.withRequestPrincipals(instance.getRequestPrincipals()); 
    this.validationEnabled = validationEnabled; 
  }
  public SourceBuilder(io.fabric8.istio.api.security.v1beta1.Source instance) {
    this(instance,false);
  }
  public SourceBuilder(io.fabric8.istio.api.security.v1beta1.Source instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withIpBlocks(instance.getIpBlocks()); 
    this.withNamespaces(instance.getNamespaces()); 
    this.withNotIpBlocks(instance.getNotIpBlocks()); 
    this.withNotNamespaces(instance.getNotNamespaces()); 
    this.withNotPrincipals(instance.getNotPrincipals()); 
    this.withNotRemoteIpBlocks(instance.getNotRemoteIpBlocks()); 
    this.withNotRequestPrincipals(instance.getNotRequestPrincipals()); 
    this.withPrincipals(instance.getPrincipals()); 
    this.withRemoteIpBlocks(instance.getRemoteIpBlocks()); 
    this.withRequestPrincipals(instance.getRequestPrincipals()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.istio.api.security.v1beta1.SourceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.istio.api.security.v1beta1.Source build() {
    Source buildable = new Source(fluent.getIpBlocks(),fluent.getNamespaces(),fluent.getNotIpBlocks(),fluent.getNotNamespaces(),fluent.getNotPrincipals(),fluent.getNotRemoteIpBlocks(),fluent.getNotRequestPrincipals(),fluent.getPrincipals(),fluent.getRemoteIpBlocks(),fluent.getRequestPrincipals());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SourceBuilder that = (SourceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> istio-model-v1beta1-6.4.0-sources.jar: io/fabric8/istio/api/security/v1beta1/SourceBuilder.java <==
package io.fabric8.istio.api.security.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SourceBuilder extends SourceFluentImpl<SourceBuilder> implements VisitableBuilder<Source,SourceBuilder>{
  public SourceBuilder() {
    this(false);
  }
  public SourceBuilder(Boolean validationEnabled) {
    this(new Source(), validationEnabled);
  }
  public SourceBuilder(SourceFluent<?> fluent) {
    this(fluent, false);
  }
  public SourceBuilder(SourceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Source(), validationEnabled);
  }
  public SourceBuilder(SourceFluent<?> fluent,Source instance) {
    this(fluent, instance, false);
  }
  public SourceBuilder(SourceFluent<?> fluent,Source instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withIpBlocks(instance.getIpBlocks()); 
    fluent.withNamespaces(instance.getNamespaces()); 
    fluent.withNotIpBlocks(instance.getNotIpBlocks()); 
    fluent.withNotNamespaces(instance.getNotNamespaces()); 
    fluent.withNotPrincipals(instance.getNotPrincipals()); 
    fluent.withNotRemoteIpBlocks(instance.getNotRemoteIpBlocks()); 
    fluent.withNotRequestPrincipals(instance.getNotRequestPrincipals()); 
    fluent.withPrincipals(instance.getPrincipals()); 
    fluent.withRemoteIpBlocks(instance.getRemoteIpBlocks()); 
    fluent.withRequestPrincipals(instance.getRequestPrincipals()); 
    this.validationEnabled = validationEnabled; 
  }
  public SourceBuilder(Source instance) {
    this(instance,false);
  }
  public SourceBuilder(Source instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withIpBlocks(instance.getIpBlocks()); 
    this.withNamespaces(instance.getNamespaces()); 
    this.withNotIpBlocks(instance.getNotIpBlocks()); 
    this.withNotNamespaces(instance.getNotNamespaces()); 
    this.withNotPrincipals(instance.getNotPrincipals()); 
    this.withNotRemoteIpBlocks(instance.getNotRemoteIpBlocks()); 
    this.withNotRequestPrincipals(instance.getNotRequestPrincipals()); 
    this.withPrincipals(instance.getPrincipals()); 
    this.withRemoteIpBlocks(instance.getRemoteIpBlocks()); 
    this.withRequestPrincipals(instance.getRequestPrincipals()); 
    this.validationEnabled = validationEnabled; 
  }
  SourceFluent<?> fluent;
  Boolean validationEnabled;
  public Source build() {
    Source buildable = new Source(fluent.getIpBlocks(),fluent.getNamespaces(),fluent.getNotIpBlocks(),fluent.getNotNamespaces(),fluent.getNotPrincipals(),fluent.getNotRemoteIpBlocks(),fluent.getNotRequestPrincipals(),fluent.getPrincipals(),fluent.getRemoteIpBlocks(),fluent.getRequestPrincipals());
    return buildable;
  }
  
}
